@@ -12,8 +12,8 @@ Eg.:
     7a1ef475-904c-4d53-8985-528d09d57414
 
 """
-from __future__ import absolute_import
+#from __future__ import absolute_import
 
-from .ruuid import uuid4
+#from .ruuid import uuid4
 
-__all__ = ['uuid4']
+#__all__ = ['uuid4']
